# Marketing Plugin for Sylius by Dedi

The objective of this plugin is to centralize the marketing strategy through the dynamic creation of data layers and the management of SEO content.

## Quickstart Installation

```bash
$ make start
$ make install
$ make configure
```

## Installation

Run `composer require dedi/sylius-marketing-plugin`

Change your `config/bundles.php` file to add the line for the plugin :

```php
<?php

return [
    //..
    Dedi\SyliusMarketingPlugin\DediSyliusMarketingPlugin::class => ['all' => true],
];
```

Create `dedi_sylius_marketing_plugin.yaml` file into `config/packages` folder to import required config

```yaml
# config/packages/dedi_sylius_marketing_plugin.yaml

imports:
  - { resource: "@DediSyliusMarketingPlugin/Resources/config/config.yaml" }

dedi_sylius_marketing:
  enabled: true

services:
  _defaults:
    autowire: true
    autoconfigure: true
    public: false
```

Register SelectItemController in config file (services/marketing.yaml per exemple)

```yaml
# config/services/marketing.yaml

services:
  Dedi\SyliusMarketingPlugin\Controller\SelectItemController:
    tags: [ 'controller.service_arguments' ]
```

Create `dedi_sylius_marketing_plugin.yaml` file into `config/routes` folder to import required routes config

```yaml
# config/routes/dedi_sylius_marketing_plugin.yaml

dedi_marketing_shop:
  resource: "@DediSyliusMarketingPlugin/Resources/config/shop_routing.yml"
```

To display datalayers, add following blocks in your layout 
```html
{# templates/bundles/SyliusShopBundle/layout.html.twig #}
<!DOCTYPE html>

<html>
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">

    {% block datalayer %}
        {{ sylius_template_event('dedi_sylius_marketing_plugin.datalayer') }}
    {% endblock %}

    <meta content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no" name="viewport">
</head>
<body>
...
{% block javascripts %}
    ...
    {{ sylius_template_event('dedi_sylius_marketing_plugin.shop.select_item.javascripts') }}
{% endblock %}
</body>
</html>
```

## Custom Datalayers

### SelectItem

Add two attributes to items that will trigger selectItem datalayer :
- `data-select-item` attribute containing product id
- `data-item-position` attribute containing product position in the listing

### Newsletter

To add custom trigger for newsletter datalayer, override `src/EventListener/NewsletterEventListener.php` file.

## Implementation with MonsieurBiz

To change default search route as MonsieurBizSearchPlugin uses a custom one, add `searchRouteName` parameter in `config/packages/dedi_sylius_marketing_plugin.yaml` file.
```yaml
# config/packages/dedi_sylius_marketing_plugin.yaml

imports:
  - { resource: "@DediSyliusMarketingPlugin/Resources/config/config.yaml" }

dedi_sylius_marketing:
  searchRouteName: 'monsieurbiz_sylius_search_search'
```

MonsieurBizSearchPlugin does not use sylius sonata event to render products and it uses specific components to retrieve data from elasticsearch. 
In order to generate `view_item_list` dataLayer with MonsieurBizSearchPlugin, you can make following implementation of `RequestProductExtractorInterface`.
```yaml

dedi_sylius_marketing:
  dedi_sylius_marketing.extractor.request_product:
    class: App\Marketing\Extractor\RequestProductMonsieurBizExtractor
```

See implemention here : [MONSIEURBIZ_EXTRACTOR.md](docs/MONSIEURBIZ_EXTRACTOR.md).

You can also consult implementation for BitBagElasticSearch here: [BITBAG_ELASTIC_SEARCH_EXTRACTOR.md](docs/BITBAG_ELASTIC_SEARCH_EXTRACTOR.md). 